@@ -49,7 +49,6 @@
 
 package com.openexchange.halo.json;
 
-import java.util.Collection;
 import java.util.Map;
 import com.google.common.collect.ImmutableMap;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
@@ -84,10 +83,4 @@ public class HaloActionFactory implements AJAXActionServiceFactory {
     public AJAXActionService createActionService(String action) throws OXException {
         return actions.get(action);
     }
-
-    @Override
-    public Collection<?> getSupportedServices() {
-        return null;
-    }
-
 }
